@@ -886,14 +886,12 @@ class Agent(object):
 			if reattempt:
 				try:
 					output = utils.__execute__([f"ssh-add", "-D"])
-					print("delete output:",output)
 				except: a=1
 				try:
 					output = utils.__execute__([f"ssh-add", "-k"])
-					print("kill output:",output)
 				except: a=1
 				try:
-					output = utils.__execute_script__(f"eval `ssh-agent`", shell=True)
+					output = utils.__execute__(f"ssh-agent")
 					try: 
 						SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
 						os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
@@ -902,7 +900,6 @@ class Agent(object):
 						SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
 						os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
 					except: a=1
-					print("restart output:",output)
 				except: a=1
 				return self.add(
 					# the keys path.
@@ -988,16 +985,21 @@ class Agent(object):
 			elif "Failed to communicate" in output or "agent refused operation" in output or "Error connecting to agent" in output or "Connection refused" in output:
 				if reattempt:
 					try:
-						output = subprocess.check_output([f"ssh-add", "-D"])
-						print("delete output:",output)
+						output = utils.__execute__([f"ssh-add", "-D"])
 					except: a=1
 					try:
-						output = subprocess.check_output([f"ssh-add", "-k"])
-						print("kill output:",output)
+						output = utils.__execute__([f"ssh-add", "-k"])
 					except: a=1
 					try:
-						output = subprocess.check_output([f"eval", "`ssh-agent`"])
-						print("restart output:",output)
+						output = utils.__execute__(f"ssh-agent")
+						try: 
+							SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
+							os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
+						except: a=1
+						try: 
+							SSH_AGENT_PID = output.split("SSH_AGENT_PID=")[1].split(";")[0]
+							os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
+						except: a=1
 					except: a=1
 					return self.add(
 						# the keys path.
